brokerlso package — brokerlso 0.0.1 documentation

# brokerlso package

## Submodules

## brokerlso.qmfv2 module

Command messages for Qpid Management Framework (QMF) version 2

class `brokerlso.qmfv2.` `RequestCmd`

  Bases: `object`

  Craft QMFv2 command messages

  `create_binding`(name, strict=True, auto_delete=False, auto_delete_timeout=10)

    Create message content and properties to create binding with QMFv2

    Parameters: | name (str) – Name of binding to create in format “exchange/queue/key” strict (bool) – Whether command should fail when unrecognized properties are provided Not used by QMFv2 Default: True auto_delete (bool) – Whether exchange should be auto deleted Default: False auto_delete_timeout (int) – Timeout in seconds for auto deleting exchange Default: 10
    Returns: | Tuple containing content and method properties

  `create_exchange`(name, type_='fanout', strict=True, auto_delete=False, auto_delete_timeout=10)

    Create message content and properties to create exchange with QMFv2

    Parameters: | name (str) – Name of exchange to create type (str) – Type of exchange to create Possible values are: direct, fanout, topic? strict (bool) – Whether command should fail when unrecognized properties are provided Not used by QMFv2 Default: True auto_delete (bool) – Whether exchange should be auto deleted Default: False auto_delete_timeout (int) – Timeout in seconds for auto deleting exchange Default: 10
    Returns: | Tuple containing content and method properties

  `create_queue`(name, strict=True, auto_delete=False, auto_delete_timeout=10)

    Create message content and properties to create queue with QMFv2

    Parameters: | name (str) – Name of queue to create strict (bool) – Whether command should fail when unrecognized properties are provided Not used by QMFv2 Default: True auto_delete (bool) – Whether queue should be auto deleted Default: False auto_delete_timeout (int) – Timeout in seconds for auto deleting queue Default: 10
    Returns: | Tuple containing content and method properties

  `delete_binding`(name)

    Create message content and properties to delete exchange with QMFv2

    Parameters: | name (str) – Name of exchange to delete in format “exchange/queue/key”
    Returns: | Tuple containing content and method properties

  `delete_exchange`(name)

    Create message content and properties to delete exchange with QMFv2

    Parameters: | name (str) – Name of exchange to delete
    Returns: | Tuple containing content and method properties

  `delete_queue`(name)

    Create message content and properties to delete queue with QMFv2

    Parameters: | name (str) – Name of queue to delete
    Returns: | Tuple containing content and method properties

  `list_exchanges`()

    Create message content and properties to list all exchanges with QMFv2

    Returns: | Tuple containing content and query properties

  `list_queues`()

    Create message content and properties to list all queues with QMFv2

    Returns: | Tuple containing content and query properties

## Module contents